@@ -7,7 +7,7 @@ set -e
 
 PROJECT_DIR=$(basename ${PWD})
 
-GIT_TAG=kubevirt-1.4.0-14
+GIT_TAG=kubevirt-2.0.0-14.8
 LD_FLAGS="-w -X github.com/openshift/console/version.Version=${GIT_TAG}"
 
 CGO_ENABLED=0 go build -ldflags "${LD_FLAGS}" -o bin/bridge github.com/openshift/console/cmd/bridge
