@@ -31,6 +31,9 @@ const (
 	// Well-known location of Prometheus service for OpenShift. This is only accessible in-cluster.
 	openshiftPrometheusHost = "prometheus-k8s.openshift-monitoring.svc:9091"
 
+	// The tenancy service port (9092) performs RBAC checks for namespace-specific queries.
+	openshiftPrometheusTenancyHost = "prometheus-k8s.openshift-monitoring.svc:9092"
+
 	// Well-known location of Alert Manager service for OpenShift. This is only accessible in-cluster.
 	openshiftAlertManagerHost = "alertmanager-main.openshift-monitoring.svc:9094"
 )
@@ -49,8 +52,6 @@ func main() {
 	// See https://github.com/openshift/service-serving-cert-signer
 	fServiceCAFile := fs.String("service-ca-file", "", "CA bundle for OpenShift services signed with the service signing certificates.")
 
-	fTectonicClusterName := fs.String("tectonic-cluster-name", "tectonic", "The Tectonic cluster name.")
-
 	fUserAuth := fs.String("user-auth", "disabled", "disabled | oidc | openshift")
 	fUserAuthOIDCIssuerURL := fs.String("user-auth-oidc-issuer-url", "", "The OIDC/OAuth2 issuer URL.")
 	fUserAuthOIDCCAFile := fs.String("user-auth-oidc-ca-file", "", "PEM file for the OIDC/OAuth2 issuer.")
@@ -82,8 +83,10 @@ func main() {
 	fK8sPublicEndpoint := fs.String("k8s-public-endpoint", "", "Endpoint to use when rendering kubeconfigs for clients. Useful for when bridge uses an internal endpoint clients can't access for communicating with the API server.")
 
 	fDexAPIHost := fs.String("dex-api-host", "", "Target host and port of the Dex API service.")
-	fBranding := fs.String("branding", "okd", "Console branding for the masthead logo and title. One of okd, openshift, okdvirt, openshiftvirt, ocp, online, or dedicated. Defaults to okd.")
+	fBranding := fs.String("branding", "okd", "Console branding for the masthead logo and title. One of okd, openshift, okdvirt, openshiftvirt, ocp, online, dedicated, or azure. Defaults to okd.")
 	fDocumentationBaseURL := fs.String("documentation-base-url", "", "The base URL for documentation links.")
+	fRegistry := fs.String("registry", "", "The container registry in the format [DOMAIN]/[NAMESPACE]/[PATH]. Example: quay.io/kubevirt")
+	fV2vImageTag := fs.String("v2v-image-tag", "", "Tag for V2V conversion images.")
 	fGoogleTagManagerID := fs.String("google-tag-manager-id", "", "Google Tag Manager ID. External analytics are disabled if this is not set.")
 
 	fLoadTestFactor := fs.Int("load-test-factor", 0, "DEV ONLY. The factor used to multiply k8s API list responses for load testing purposes.")
@@ -140,10 +143,6 @@ func main() {
 	if branding == "origin" {
 		branding = "okd"
 	}
-	// Temporarily default okd to openshift
-	if branding == "okd" {
-		branding = "openshift"
-	}
 	switch branding {
 	case "okd":
 	case "okdvirt":
@@ -152,8 +151,9 @@ func main() {
 	case "ocp":
 	case "online":
 	case "dedicated":
+	case "azure":
 	default:
-		flagFatalf("branding", "value must be one of okd, okdvirt, openshiftvirt, openshift, okdvirt, ocp, or online")
+		flagFatalf("branding", "value must be one of okd, okdvirt, openshiftvirt, openshift, ocp, online, dedicated, or azure")
 	}
 
 	srv := &server.Server{
@@ -162,11 +162,12 @@ func main() {
 		BaseURL:              baseURL,
 		LogoutRedirect:       logoutRedirect,
 		TectonicCACertFile:   caCertFilePath,
-		ClusterName:          *fTectonicClusterName,
 		Branding:             branding,
 		DocumentationBaseURL: documentationBaseURL,
 		GoogleTagManagerID:   *fGoogleTagManagerID,
 		LoadTestFactor:       *fLoadTestFactor,
+		Registry:             *fRegistry, // skip validation
+		V2vImageTag:          *fV2vImageTag,
 	}
 
 	if (*fKubectlClientID == "") != (*fKubectlClientSecret == "" && *fKubectlClientSecretFile == "") {
@@ -191,17 +192,8 @@ func main() {
 
 	var (
 		// Hold on to raw certificates so we can render them in kubeconfig files.
-		dexCertPEM []byte
 		k8sCertPEM []byte
 	)
-	if *fCAFile != "" {
-		var err error
-
-		if dexCertPEM, err = ioutil.ReadFile(*fCAFile); err != nil {
-			log.Fatalf("Failed to read cert file: %v", err)
-		}
-
-	}
 
 	var (
 		k8sAuthServiceAccountBearerToken string
@@ -273,6 +265,11 @@ func main() {
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
 				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusHost, Path: "/api"},
 			}
+			srv.PrometheusTenancyProxyConfig = &proxy.Config{
+				TLSClientConfig: monitoringProxyTLSConfig,
+				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
+				Endpoint:        &url.URL{Scheme: "https", Host: openshiftPrometheusTenancyHost, Path: "/api"},
+			}
 			srv.AlertManagerProxyConfig = &proxy.Config{
 				TLSClientConfig: monitoringProxyTLSConfig,
 				HeaderBlacklist: []string{"Cookie", "X-CSRFToken"},
@@ -369,7 +366,7 @@ func main() {
 
 			// Use the k8s CA file for OpenShift OAuth metadata discovery.
 			// This might be different than IssuerCA.
-			DiscoveryCA: caCertFilePath,
+			K8sCA: caCertFilePath,
 
 			ErrorURL:   authLoginErrorEndpoint,
 			SuccessURL: authLoginSuccessEndpoint,
@@ -386,60 +383,16 @@ func main() {
 			// Assume kubectl is the client ID trusted by kubernetes, not bridge.
 			// These additional flags causes Dex to issue an ID token valid for
 			// both bridge and kubernetes.
-			//
-			// For design see: https://github.com/coreos-inc/tectonic/blob/master/docs-internal/tectonic-identity.md
 			oidcClientConfig.Scope = append(
 				oidcClientConfig.Scope,
 				"audience:server:client_id:"+*fUserAuthOIDCClientID,
 				"audience:server:client_id:"+*fKubectlClientID,
 			)
 
-			kubectlClientSecret := *fKubectlClientSecret
-			if *fKubectlClientSecretFile != "" {
-				buf, err := ioutil.ReadFile(*fKubectlClientSecretFile)
-				if err != nil {
-					log.Fatalf("Failed to read client secret file: %v", err)
-				}
-				kubectlClientSecret = string(buf)
-			}
-
-			// Configure an OpenID Connect config for kubectl. This lets us issue
-			// refresh tokens that kubectl can redeem using its own credentials.
-			kubectlAuthConfig := &auth.Config{
-				IssuerURL:    userAuthOIDCIssuerURL.String(),
-				IssuerCA:     *fCAFile,
-				ClientID:     *fKubectlClientID,
-				ClientSecret: kubectlClientSecret,
-				// The magic "out of band" redirect URL.
-				RedirectURL: "urn:ietf:wg:oauth:2.0:oob",
-				// Request a refresh token with the "offline_access" scope.
-				Scope: []string{"openid", "email", "profile", "offline_access", "groups"},
-
-				ErrorURL:   authLoginErrorEndpoint,
-				SuccessURL: authLoginSuccessEndpoint,
-
-				CookiePath:    cookiePath,
-				RefererPath:   refererPath,
-				SecureCookies: secureCookies,
-			}
-
-			if srv.KubectlAuther, err = auth.NewAuthenticator(context.Background(), kubectlAuthConfig); err != nil {
-				log.Fatalf("Error initializing kubectl authenticator: %v", err)
-			}
-
-			srv.KubeConfigTmpl = server.NewKubeConfigTmpl(
-				*fTectonicClusterName,
-				*fKubectlClientID,
-				*fKubectlClientSecret,
-				apiServerEndpoint,
-				userAuthOIDCIssuerURL.String(),
-				k8sCertPEM,
-				dexCertPEM,
-			)
 		}
 
 		if srv.Auther, err = auth.NewAuthenticator(context.Background(), oidcClientConfig); err != nil {
-			log.Fatalf("Error initializing OIDC authenticator: %v", err)
+			log.Fatalf("Error initializing authenticator: %v", err)
 		}
 	case "disabled":
 		log.Warningf("running with AUTHENTICATION DISABLED!")
