@@ -14,13 +14,17 @@ import {
   WindowScroller,
 } from 'react-virtualized';
 
-import { alertState, alertStateOrder, silenceState, silenceStateOrder } from '../../monitoring';
 import { UIActions } from '../../ui/ui-actions';
 import { ingressValidHosts } from '../ingress';
 import { routeStatus } from '../routes';
-import { getClusterOperatorStatus } from '../cluster-settings/cluster-operator';
 import { secretTypeFilterReducer } from '../secret';
 import { bindingType, roleType } from '../RBAC';
+import {
+  alertState,
+  alertStateOrder,
+  silenceState,
+  silenceStateOrder,
+} from '../../monitoring';
 import {
   containerLinuxUpdateOperator,
   EmptyBox,
@@ -33,7 +37,7 @@ import {
 } from '../utils';
 import {
   getJobTypeAndCompletions,
-  isNodeReady,
+  nodeStatus,
   K8sKind,
   K8sResourceKind,
   K8sResourceKindReference,
@@ -43,9 +47,11 @@ import {
   podReadiness,
   serviceCatalogStatus,
   serviceClassDisplayName,
+  getClusterOperatorStatus,
+  getClusterOperatorVersion,
 } from '../../module/k8s';
 
-import { getVmStatus } from 'kubevirt-web-ui-components';
+import { getSimpleVmStatus, getHostStatus } from 'kubevirt-web-ui-components';
 
 const fuzzyCaseInsensitive = (a, b) => fuzzy(_.toLower(a), _.toLower(b));
 
@@ -92,9 +98,13 @@ const listFilters = {
     return phases.selected.has(phase) || !_.includes(phases.all, phase);
   },
 
-  'node-status': (status, node) => {
-    const isReady = isNodeReady(node);
-    return status === 'all' || (status === 'ready' && isReady) || (status === 'notReady' && !isReady);
+  'node-status': (statuses, node) => {
+    if (!statuses || !statuses.selected || !statuses.selected.size) {
+      return true;
+    }
+
+    const status = nodeStatus(node);
+    return statuses.selected.has(status) || !_.includes(statuses.all, status);
   },
 
   'clusterserviceversion-resource-kind': (filters, resource) => {
@@ -103,6 +113,16 @@ const listFilters = {
     }
     return filters.selected.has(resource.kind);
   },
+  'clusterserviceversion-status': (filters, csv) => {
+    if (!filters || !filters.selected || !filters.selected.size) {
+      return true;
+    }
+    return filters.selected.has(_.get(csv.status, 'reason')) || !_.includes(filters.all, _.get(csv.status, 'reason'));
+  },
+
+  'packagemanifest-name': (filter, pkg) => fuzzyCaseInsensitive(filter, (pkg.status.defaultChannel
+    ? pkg.status.channels.find(ch => ch.name === pkg.status.defaultChannel)
+    : pkg.status.channels[0]).currentCSVDesc.displayName),
 
   'build-status': (phases, build) => {
     if (!phases || !phases.selected || !phases.selected.size) {
@@ -165,7 +185,12 @@ const listFilters = {
 
   'vm-status' : (statuses, vm) => {
     // TODO: figure out how to get VM pods here
-    const status = getVmStatus(vm);
+    const status = getSimpleVmStatus(vm);
+    return statuses.selected.has(status) || !_.includes(statuses.all, status);
+  },
+
+  'baremetalhost-status': (statuses, host) => {
+    const status = getHostStatus(host);
     return statuses.selected.has(status) || !_.includes(statuses.all, status);
   },
 
@@ -228,6 +253,8 @@ const sorts = {
   serviceClassDisplayName,
   silenceStateOrder,
   string: val => JSON.stringify(val),
+  getClusterOperatorStatus,
+  getClusterOperatorVersion,
 };
 
 export class ColHead extends React.Component<ColHeadProps> {
@@ -289,6 +316,10 @@ export const WorkloadListHeader = props => <ListHeader>
   <ColHead {...props} className="col-lg-3 hidden-md hidden-sm hidden-xs" sortField="spec.selector">Pod Selector</ColHead>
 </ListHeader>;
 
+const getRowKey = (obj, index) => {
+  return _.get(obj, 'rowKey') || _.get(obj, 'metadata.uid', index);
+};
+
 const VirtualRows: React.SFC<RowsProps> = (props) => {
   const { mock, label } = props;
 
@@ -309,7 +340,7 @@ const VirtualRows: React.SFC<RowsProps> = (props) => {
       parent={parent}
       rowIndex={index}>
       <div style={style} className="co-m-row">
-        <Row key={_.get(obj, 'metadata.uid', index)} obj={obj} expand={expand} kindObj={kindObj} index={index} />
+        <Row key={getRowKey(obj, index)} obj={obj} expand={expand} kindObj={kindObj} index={index} />
       </div>
     </CellMeasurer>;
   };
@@ -348,7 +379,7 @@ VirtualRows.propTypes = {
   data: PropTypes.arrayOf(PropTypes.object),
   expand: PropTypes.bool,
   Row: PropTypes.func.isRequired,
-  kindObj: PropTypes.any.isRequired,
+  kindObj: PropTypes.any,
   label: PropTypes.string,
   mock: PropTypes.bool,
 };
@@ -357,7 +388,7 @@ const Rows: React.SFC<RowsProps> = (props) => {
   const {Row, expand, kindObj} = props;
 
   return <div className="co-m-table-grid__body">
-    { props.data.map((obj, i) => <div key={_.get(obj, 'metadata.uid', i)} className="co-m-row">
+    { props.data.map((obj, i) => <div key={getRowKey(obj, i)} className="co-m-row">
       <Row obj={obj} expand={expand} kindObj={kindObj} />
     </div>) }
   </div>;
@@ -435,11 +466,9 @@ export const List = connect(stateToProps, {sortList: UIActions.sortList})(
     };
 
     render() {
-      const {currentSortField, currentSortFunc, currentSortOrder, expand, Header, label, listId, mock, Row, sortList} = this.props;
+      const {currentSortField, currentSortFunc, currentSortOrder, expand, Header, label, listId, mock, Row, sortList, virtualize = true} = this.props;
       const componentProps: any = _.pick(this.props, ['data', 'filters', 'selected', 'match', 'kindObj']);
-
-      const ListRows = this.props.virtualize ? VirtualRows : Rows;
-
+      const ListRows = virtualize ? VirtualRows : Rows;
       const children = <React.Fragment>
         <Header
           {...componentProps}
