@@ -1,5 +1,4 @@
 /* eslint-disable no-unused-vars, no-undef */
-
 import * as _ from 'lodash-es';
 import * as classnames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
@@ -12,10 +11,12 @@ import { Toolbar, EmptyState } from 'patternfly-react';
 
 import { coFetchJSON } from '../../co-fetch';
 import { getBuildNumber } from '../../module/k8s/builds';
-import { prometheusBasePath } from '../graphs';
+import { prometheusTenancyBasePath } from '../graphs';
 import { TextFilter } from '../factory';
+import { PodStatus } from '../pod';
 import { UIActions, formatNamespacedRouteForResource } from '../../ui/ui-actions';
 import {
+  apiVersionForModel,
   K8sResourceKind,
   LabelSelector,
 } from '../../module/k8s';
@@ -27,10 +28,13 @@ import {
   DaemonSetModel,
   DeploymentModel,
   DeploymentConfigModel,
+  PodModel,
   ProjectModel,
   ReplicationControllerModel,
   ReplicaSetModel,
   StatefulSetModel,
+  VirtualMachineModel,
+  VirtualMachineInstanceMigrationModel,
 } from '../../models';
 import {
   ActionsMenu,
@@ -40,35 +44,49 @@ import {
   Firehose,
   StatusBox,
   EmptyBox,
+  resourceObjPath,
 } from '../utils';
 
 import { overviewMenuActions, OverviewNamespaceDashboard } from './namespace-overview';
 import { ProjectOverview } from './project-overview';
 import { ResourceOverviewPage } from './resource-overview-page';
+import { FLAGS, featureReducerName } from '../../features';
 
-enum View {
-  Resources = 'resources',
-  Dashboard = 'dashboard',
-}
+import { VmStatus } from 'kubevirt-web-ui-components';
+import { OverviewViewOption, OverviewSpecialGroup } from './constants';
 
-// The following values should not be valid label keys to avoid conflicts.
-// https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#syntax-and-character-set
-const GROUP_BY_APPLICATION = '#GROUP_BY_APPLICATION#';
-const GROUP_BY_RESOURCE = '#GROUP_BY_RESOURCE#';
-const EMPTY_GROUP_NAME = 'other resources';
 
-const DEPLOYMENT_REVISION_ANNOTATION = 'deployment.kubernetes.io/revision';
+// List of container status waiting reason values that we should call out as errors in project status rows.
+const CONTAINER_WAITING_STATE_ERROR_REASONS = ['CrashLoopBackOff', 'ErrImagePull', 'ImagePullBackOff'];
+
+// Annotation key for deployment config latest version
 const DEPLOYMENT_CONFIG_LATEST_VERSION_ANNOTATION = 'openshift.io/deployment-config.latest-version';
+
+// Annotation key for deployment phase
 const DEPLOYMENT_PHASE_ANNOTATION = 'openshift.io/deployment.phase';
-const TRIGGERS_ANNOTATION = 'image.openshift.io/triggers';
+
+// Annotaton key for deployment revision
+const DEPLOYMENT_REVISION_ANNOTATION = 'deployment.kubernetes.io/revision';
+
+// Display name for default overview group.
+// Should not be a valid label key to avoid conflicts. https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#syntax-and-character-setexport
+const DEFAULT_GROUP_NAME = 'other resources';
+
+// Interval at which metrics are retrieved and updated
 const METRICS_POLL_INTERVAL = 30 * 1000;
 
+// Namespace prefixes that are reserved and should not have calls to action on empty state
+const RESERVED_NS_PREFIXES = ['openshift-', 'kube-', 'kubernetes-'];
+
+// Annotation key for image triggers
+const TRIGGERS_ANNOTATION = 'image.openshift.io/triggers';
+
 const asOverviewGroups = (keyedItems: { [name: string]: OverviewItem[] }): OverviewGroup[] => {
   const compareGroups = (a: OverviewGroup, b: OverviewGroup) => {
-    if (a.name === EMPTY_GROUP_NAME) {
+    if (a.name === DEFAULT_GROUP_NAME) {
       return 1;
     }
-    if (b.name === EMPTY_GROUP_NAME) {
+    if (b.name === DEFAULT_GROUP_NAME) {
       return -1;
     }
     return a.name.localeCompare(b.name);
@@ -84,7 +102,7 @@ const asOverviewGroups = (keyedItems: { [name: string]: OverviewItem[] }): Overv
 
 const getApplication = (item: OverviewItem): string => {
   const labels = _.get(item, 'obj.metadata.labels') || {};
-  return labels['app.kubernetes.io/part-of'] || labels['app.kubernetes.io/name'] || labels.app || EMPTY_GROUP_NAME;
+  return labels['app.kubernetes.io/part-of'] || labels['app.kubernetes.io/name'] || labels.app || DEFAULT_GROUP_NAME;
 };
 
 const groupByApplication = (items: OverviewItem[]): OverviewGroup[] => {
@@ -98,24 +116,21 @@ const groupByResource = (items: OverviewItem[]): OverviewGroup[] => {
 };
 
 const groupByLabel = (items: OverviewItem[], label: string): OverviewGroup[] => {
-  const byLabel = _.groupBy(items, (item): string => _.get(item, ['obj', 'metadata', 'labels', label]) || EMPTY_GROUP_NAME);
+  const byLabel = _.groupBy(items, (item): string => _.get(item, ['obj', 'metadata', 'labels', label]) || DEFAULT_GROUP_NAME);
   return asOverviewGroups(byLabel);
 };
 
 const groupItems = (items: OverviewItem[], selectedGroup: string): OverviewGroup[] => {
   switch (selectedGroup) {
-    case GROUP_BY_APPLICATION:
+    case OverviewSpecialGroup.GROUP_BY_APPLICATION:
       return groupByApplication(items);
-    case GROUP_BY_RESOURCE:
+    case OverviewSpecialGroup.GROUP_BY_RESOURCE:
       return groupByResource(items);
     default:
       return groupByLabel(items, selectedGroup);
   }
 };
 
-// List of container status waiting reason values that we should call out as errors in overview rows.
-const CONTAINER_WAITING_STATE_ERROR_REASONS = ['CrashLoopBackOff', 'ErrImagePull', 'ImagePullBackOff'];
-
 const getAnnotation = (obj: K8sResourceKind, annotation: string): string => {
   return _.get(obj, ['metadata', 'annotations', annotation]);
 };
@@ -149,7 +164,7 @@ const podAlertKey = (alert: any, pod: K8sResourceKind, containerName: string = '
   return `${alert}--${id}--${containerName}`;
 };
 
-const getPodAlerts = (pod: K8sResourceKind): any => {
+const getPodAlerts = (pod: K8sResourceKind): OverviewItemAlerts => {
   const alerts = {};
   const statuses = [
     ..._.get(pod, 'status.initContainerStatuses', []),
@@ -179,12 +194,12 @@ const getPodAlerts = (pod: K8sResourceKind): any => {
   return alerts;
 };
 
-const combinePodAlerts = (pods: K8sResourceKind[]): any => _.reduce(pods, (acc, pod) => ({
+const combinePodAlerts = (pods: K8sResourceKind[]): OverviewItemAlerts => _.reduce(pods, (acc, pod) => ({
   ...acc,
   ...getPodAlerts(pod),
 }), {});
 
-const getReplicationControllerAlerts = (rc: K8sResourceKind): any => {
+const getReplicationControllerAlerts = (rc: K8sResourceKind): OverviewItemAlerts => {
   const phase = getDeploymentPhase(rc);
   const version = getDeploymentConfigVersion(rc);
   const label = _.isFinite(version) ? `#${version}` : rc.metadata.name;
@@ -209,6 +224,18 @@ const getReplicationControllerAlerts = (rc: K8sResourceKind): any => {
   }
 };
 
+const getResourcePausedAlert = (resource): OverviewItemAlerts => {
+  if (!resource.spec.paused) {
+    return {};
+  }
+  return {
+    [`${resource.metadata.uid}--Paused`]: {
+      severity: 'info',
+      message: `${resource.metadata.name} is paused.`,
+    },
+  };
+};
+
 const getOwnedResources = ({metadata:{uid}}: K8sResourceKind, resources: K8sResourceKind[]): K8sResourceKind[] => {
   return _.filter(resources, ({metadata:{ownerReferences}}) => {
     return _.some(ownerReferences, {
@@ -277,8 +304,14 @@ const sortBuilds = (builds: K8sResourceKind[]): K8sResourceKind[] => {
   return builds.sort(byBuildNumber);
 };
 
-const reservedNSPrefixes = ['openshift-', 'kube-', 'kubernetes-'];
-const isReservedNamespace = (ns: string) => ns === 'default' || ns === 'openshift' || reservedNSPrefixes.some(prefix => _.startsWith(ns, prefix));
+const isReservedNamespace = (ns: string) => ns === 'default' || ns === 'openshift' || RESERVED_NS_PREFIXES.some(prefix => _.startsWith(ns, prefix));
+
+const OverviewItemReadiness: React.SFC<OverviewItemReadinessProps> = ({desired = 0, ready = 0, resource}) => {
+  const href = `${resourceObjPath(resource, resource.kind)}/pods`;
+  return <Link to={href}>
+    {ready} of {desired} pods
+  </Link>;
+};
 
 const overviewEmptyStateToProps = ({UI}) => ({
   activeNamespace: UI.get('activeNamespace'),
@@ -314,106 +347,114 @@ const OverviewEmptyState = connect(overviewEmptyStateToProps)(({activeNamespace,
 });
 
 const headingStateToProps = ({UI}): OverviewHeadingPropsFromState => {
-  const selectedView = UI.getIn(['overview', 'selectedView']);
-  return { selectedView };
+  const {selectedView, selectedGroup, groupOptions, filterValue} = UI.get('overview').toJS();
+  return {groupOptions, selectedGroup, selectedView, filterValue};
 };
 
 const headingDispatchToProps = (dispatch): OverviewHeadingPropsFromDispatch => ({
-  selectView: (view: View) => dispatch(UIActions.selectOverviewView(view)),
+  selectView: (view: OverviewViewOption) => dispatch(UIActions.selectOverviewView(view)),
+  selectGroup: (group: string) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
+  changeFilter: (value: string) => dispatch(UIActions.updateOverviewFilterValue(value)),
 });
 
-const OverviewHeading_: React.SFC<OverviewHeadingProps> = ({disabled, firstLabel = '', groupOptions, handleFilterChange = _.noop, handleGroupChange = _.noop, selectedGroup = '', selectView, selectedView, title, project}) => (
-  <div className={classnames('co-m-nav-title co-m-nav-title--overview', { 'overview-filter-group': selectedView === View.Resources })}>
-    {
-      title &&
-      <h1 className="co-m-pane__heading co-m-pane__heading--overview">
-        <div className="co-m-pane__name co-m-pane__name--overview">{title}</div>
-        <div className="toolbar-pf">
-          <div className="form-group toolbar-pf-view-selector overview-view-selector">
-            <button
-              type="button"
-              className={classnames('btn btn-link', { active: selectedView === View.Resources })}
-              aria-label="Resources"
-              title="Resources"
-              disabled={disabled}
-              onClick={() => selectView(View.Resources)}
-            >
-              <i className="fa fa-list-ul" aria-hidden="true" />
-            </button>
-            <button
-              type="button"
-              className={classnames('btn btn-link', { active: selectedView === View.Dashboard })}
-              aria-label="Dashboard"
-              title="Dashboard"
-              disabled={disabled}
-              onClick={() => selectView(View.Dashboard)}
-            >
-              <i className="fa fa-dashboard" aria-hidden="true" />
-            </button>
-          </div>
+class OverviewHeading_ extends React.Component<OverviewHeadingProps> {
+  componentWillUnmount() {
+    // Resets the filter value so that it is not retained when navigating to other pages.
+    this.props.changeFilter('');
+  }
+
+  render() {
+    const {changeFilter, disabled, filterValue, firstLabel = '', groupOptions, selectGroup, selectedGroup, selectView, selectedView, title, project} = this.props;
+    return <div className={classnames('co-m-nav-title co-m-nav-title--overview', { 'overview-filter-group': selectedView === OverviewViewOption.RESOURCES })}>
+      {
+        title &&
+        <h1 className="co-m-pane__heading co-m-pane__heading--overview">
+          <div className="co-m-pane__name co-m-pane__name--overview">{title}</div>
+        </h1>
+      }
+      {!_.isEmpty(project) && <div className={classnames('overview-view-selector', {'selected-view__resources': selectedView === OverviewViewOption.RESOURCES })}>
+        <div className="form-group btn-group">
+          <button
+            type="button"
+            className={classnames('btn btn-default', { 'btn-primary': selectedView === OverviewViewOption.RESOURCES })}
+            aria-label="Resources"
+            title="Resources"
+            disabled={disabled}
+            onClick={() => selectView(OverviewViewOption.RESOURCES)}
+          >
+            <i className="fa fa-list-ul" aria-hidden="true" />
+            Resources
+          </button>
+          <button
+            type="button"
+            className={classnames('btn btn-default', { 'btn-primary': selectedView === OverviewViewOption.DASHBOARD })}
+            aria-label="Dashboard"
+            title="Dashboard"
+            disabled={disabled}
+            onClick={() => selectView(OverviewViewOption.DASHBOARD)}
+          >
+            <i className="fa fa-dashboard" aria-hidden="true" />
+            Dashboard
+          </button>
         </div>
-      </h1>
-    }
-    <Toolbar className="overview-toolbar">
-      <Toolbar.RightContent>
-        {selectedView === View.Resources && <React.Fragment>
-          <div className="form-group overview-toolbar__form-group">
-            <Dropdown
-              className="overview-toolbar__dropdown"
-              menuClassName="dropdown-menu--text-wrap"
-              disabled={disabled}
-              items={groupOptions}
-              onChange={handleGroupChange}
-              titlePrefix="Group by"
-              title={groupOptions[selectedGroup]}
-              spacerBefore={new Set([firstLabel])}
-              headerBefore={{[firstLabel]: 'Label'}}
-            />
-          </div>
-          <div className="form-group overview-toolbar__form-group">
-            <div className="overview-toolbar__text-filter">
-              <TextFilter
-                autoFocus={!disabled}
-                defaultValue={''}
-                disabled={disabled}
-                label="Resources by name"
-                onChange={handleFilterChange}
-              />
-            </div>
-          </div>
-        </React.Fragment>}
-        {selectedView === View.Dashboard && !_.isEmpty(project) && <div className="form-group">
-          <ActionsMenu actions={overviewMenuActions.map((a: KebabAction) => a(ProjectModel, project))} />
-        </div>}
-      </Toolbar.RightContent>
-    </Toolbar>
-  </div>
-);
+        <Toolbar className="overview-toolbar" preventSubmit>
+          <Toolbar.RightContent>
+            {selectedView === OverviewViewOption.RESOURCES && <React.Fragment>
+              <div className="form-group overview-toolbar__form-group">
+                <Dropdown
+                  className="overview-toolbar__dropdown"
+                  menuClassName="dropdown-menu--text-wrap"
+                  items={groupOptions}
+                  onChange={selectGroup}
+                  titlePrefix="Group by"
+                  title={groupOptions[selectedGroup] || 'Select Category'}
+                  spacerBefore={new Set([firstLabel])}
+                  headerBefore={{[firstLabel]: 'Label'}}
+                />
+              </div>
+              <div className="form-group overview-toolbar__form-group">
+                <div className="overview-toolbar__text-filter">
+                  <TextFilter
+                    autoFocus={!disabled}
+                    defaultValue={filterValue}
+                    label="by name"
+                    onChange={(e) => changeFilter(e.target.value)}
+                  />
+                </div>
+              </div>
+            </React.Fragment>}
+            {selectedView === OverviewViewOption.DASHBOARD && !_.isEmpty(project) && <div className="form-group">
+              <ActionsMenu actions={overviewMenuActions.map((a: KebabAction) => a(ProjectModel, project))} />
+            </div>}
+          </Toolbar.RightContent>
+        </Toolbar>
+      </div>}
+    </div>;
+  }
+}
 
 const OverviewHeading = connect<OverviewHeadingPropsFromState, OverviewHeadingPropsFromDispatch, OverviewHeadingOwnProps>(headingStateToProps, headingDispatchToProps)(OverviewHeading_);
 
 const mainContentStateToProps = ({UI}): OverviewMainContentPropsFromState => {
-  const metrics = UI.getIn(['overview', 'metrics']);
-  const selectedView = UI.getIn(['overview', 'selectedView']);
-  return { metrics, selectedView };
+  const {filterValue, metrics, selectedView, selectedGroup, groupOptions} = UI.get('overview').toJS();
+  return {filterValue, groupOptions, metrics, selectedGroup, selectedView};
 };
 
 const mainContentDispatchToProps = (dispatch): OverviewMainContentPropsFromDispatch => ({
+  updateGroupOptions: (groups: { [key: string]: string }) => dispatch(UIActions.updateOverviewGroupOptions(groups)),
   updateMetrics: (metrics: OverviewMetrics) => dispatch(UIActions.updateOverviewMetrics(metrics)),
   updateResources: (items: OverviewItem[]) => dispatch(UIActions.updateOverviewResources(items)),
+  updateSelectedGroup: (group: string) => dispatch(UIActions.updateOverviewSelectedGroup(group)),
 });
 
 class OverviewMainContent_ extends React.Component<OverviewMainContentProps, OverviewMainContentState> {
   private metricsInterval: any = null;
 
   readonly state: OverviewMainContentState = {
-    filterValue: '',
     items: [],
     filteredItems: [],
     groupedItems: [],
     firstLabel: '',
-    groupOptions: {},
-    selectedGroup: '',
   };
 
   componentDidMount(): void {
@@ -431,6 +472,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       daemonSets,
       deployments,
       deploymentConfigs,
+      filterValue,
       loaded,
       namespace,
       pods,
@@ -439,11 +481,11 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       routes,
       services,
       statefulSets,
-      selectedView,
+      virtualMachines,
+      selectedGroup,
     } = this.props;
-    const {filterValue, selectedGroup} = this.state;
 
-    if (!_.isEqual(namespace, prevProps.namespace)
+    if (namespace !== prevProps.namespace
       || loaded !== prevProps.loaded
       || !_.isEqual(buildConfigs, prevProps.buildConfigs)
       || !_.isEqual(builds, prevProps.builds)
@@ -455,28 +497,30 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       || !_.isEqual(replicationControllers, prevProps.replicationControllers)
       || !_.isEqual(routes, prevProps.routes)
       || !_.isEqual(services, prevProps.services)
-      || !_.isEqual(statefulSets, prevProps.statefulSets)) {
+      || !_.isEqual(statefulSets, prevProps.statefulSets)
+      || !_.isEqual(virtualMachines, prevProps.virtualMachines)) {
       this.createOverviewData();
-    } else if (filterValue !== prevState.filterValue) {
+    } else if (filterValue !== prevProps.filterValue) {
       const filteredItems = this.filterItems(this.state.items);
       this.setState({
         filteredItems,
         groupedItems: groupItems(filteredItems, selectedGroup),
       });
-    } else if (selectedGroup !== prevState.selectedGroup) {
+    } else if (selectedGroup !== prevProps.selectedGroup) {
       this.setState({
         groupedItems: groupItems(this.state.filteredItems, selectedGroup),
       });
-    } else if (selectedView !== prevProps.selectedView && selectedView === View.Dashboard) {
-      // TODO: Preserve filter when switching to dashboard view and back.
-      // OverviewHeading doesn't keep the value in state.
-      this.setState({ filterValue: '' });
+    }
+
+    // Fetch new metrics when the namespace changes.
+    if (namespace !== prevProps.namespace) {
+      clearInterval(this.metricsInterval);
+      this.fetchMetrics();
     }
   }
 
-  fetchMetrics(): void {
-    if (!prometheusBasePath) {
-      // Component is not mounted or proxy has not been set up.
+  fetchMetrics = (): void => {
+    if (!prometheusTenancyBasePath) {
       return;
     }
 
@@ -487,7 +531,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     };
 
     const promises = _.map(queries, (query, name) => {
-      const url = `${prometheusBasePath}/api/v1/query?query=${encodeURIComponent(query)}`;
+      const url = `${prometheusTenancyBasePath}/api/v1/query?namespace=${namespace}&query=${encodeURIComponent(query)}`;
       return coFetchJSON(url).then(({ data: {result} }) => {
         const byPod: MetricValuesByPod = result.reduce((acc, { metric, value }) => {
           acc[metric.pod_name] = Number(value[1]);
@@ -514,8 +558,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   }
 
   filterItems(items: OverviewItem[]): OverviewItem[] {
-    const {selectedItem} = this.props;
-    const {filterValue} = this.state;
+    const {filterValue, selectedItem} = this.props;
 
     if (!filterValue) {
       return items;
@@ -530,8 +573,8 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
 
   getGroupOptionsFromLabels(items: OverviewItem[]): any {
     const specialGroups = {
-      [GROUP_BY_APPLICATION]: 'Application',
-      [GROUP_BY_RESOURCE]: 'Resource',
+      [OverviewSpecialGroup.GROUP_BY_APPLICATION]: 'Application',
+      [OverviewSpecialGroup.GROUP_BY_RESOURCE]: 'Resource',
     };
 
     const labelKeys = _.flatMap(items, item => _.keys(_.get(item, 'obj.metadata.labels'))).sort();
@@ -562,7 +605,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
 
   getServicesForResource(resource: K8sResourceKind): K8sResourceKind[] {
     const {services} = this.props;
-    const template = _.get(resource, 'spec.template');
+    const template = resource.kind === 'Pod' ? resource : _.get(resource, 'spec.template');
     return _.filter(services.data, service => {
       const selector = new LabelSelector(_.get(service, 'spec.selector', {}));
       return selector.matches(template);
@@ -579,6 +622,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     const revision = getDeploymentConfigVersion(rc);
     const obj = {
       ...rc,
+      apiVersion: apiVersionForModel(ReplicationControllerModel),
       kind: ReplicationControllerModel.kind,
     };
     return {
@@ -605,6 +649,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   toReplicaSetItem(rs: K8sResourceKind): PodControllerOverviewItem {
     const obj = {
       ...rs,
+      apiVersion: apiVersionForModel(ReplicaSetModel),
       kind: ReplicaSetModel.kind,
     };
     const pods = this.getPodsForResource(rs);
@@ -642,7 +687,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     const triggers = _.unionWith(nativeTriggers, annotatedTriggers, _.isEqual);
     return _.flatMap(triggers, (trigger) => {
       const triggerFrom = trigger.from || _.get(trigger, 'imageChangeParams.from', {});
-      if ( triggerFrom.kind !== 'ImageStreamTag') {
+      if (triggerFrom.kind !== 'ImageStreamTag') {
         return [];
       }
       return _.reduce(buildConfigs.data, (acc, buildConfig) => {
@@ -675,21 +720,22 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const alerts = combinePodAlerts(pods);
       const obj = {
         ...ds,
+        apiVersion: apiVersionForModel(DaemonSetModel),
         kind: DaemonSetModel.kind,
       };
-      const readiness = {
-        desired: ds.status.desiredNumberScheduled || 0,
-        ready: ds.status.currentNumberScheduled || 0,
-      };
-
+      const status = <OverviewItemReadiness
+        desired={ds.status.desiredNumberScheduled}
+        ready={ds.status.currentNumberScheduled}
+        resource={obj}
+      />;
       return {
         alerts,
         buildConfigs,
         obj,
         pods,
-        readiness,
         routes,
         services,
+        status,
       };
     });
   }
@@ -697,6 +743,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   createDeploymentItems(): OverviewItem[] {
     const {deployments} = this.props;
     return _.map(deployments.data, d => {
+      const alerts = getResourcePausedAlert(d);
       const replicaSets = this.getReplicaSetsForResource(d);
       const current = _.head(replicaSets);
       const previous = _.nth(replicaSets, 1);
@@ -706,22 +753,28 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const routes = this.getRoutesForServices(services);
       const obj = {
         ...d,
+        apiVersion: apiVersionForModel(DeploymentModel),
         kind: DeploymentModel.kind,
       };
-      const readiness = {
-        desired: d.spec.replicas || 0,
-        ready: d.status.replicas || 0,
-      };
+      // TODO: Show pod status for previous and next revisions.
+      const status = isRollingOut
+        ? <span className="text-muted">Rollout in progress...</span>
+        : <OverviewItemReadiness
+          desired={d.spec.replicas}
+          ready={d.status.replicas}
+          resource={current ? current.obj : obj}
+        />;
 
       return {
+        alerts,
         buildConfigs,
         current,
         isRollingOut,
         obj,
         previous,
-        readiness,
         routes,
         services,
+        status,
       };
     });
   }
@@ -729,6 +782,7 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
   createDeploymentConfigItems(): OverviewItem[] {
     const {deploymentConfigs} = this.props;
     return _.map(deploymentConfigs.data, dc => {
+      const alerts = getResourcePausedAlert(dc);
       const replicationControllers = this.getReplicationControllersForResource(dc);
       const current = _.head(replicationControllers);
       const previous = _.nth(replicationControllers, 1);
@@ -738,22 +792,28 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
       const routes = this.getRoutesForServices(services);
       const obj = {
         ...dc,
+        apiVersion: apiVersionForModel(DeploymentConfigModel),
         kind: DeploymentConfigModel.kind,
       };
-      const readiness = {
-        desired: dc.spec.replicas || 0,
-        ready: dc.status.replicas || 0,
-      };
 
+      // TODO: Show pod status for previous and next revisions.
+      const status = isRollingOut
+        ? <span className="text-muted">Rollout in progress...</span>
+        : <OverviewItemReadiness
+          desired={dc.spec.replicas}
+          ready={dc.status.replicas}
+          resource={current ? current.obj : obj}
+        />;
       return {
+        alerts,
         buildConfigs,
         current,
         isRollingOut,
         obj,
         previous,
-        readiness,
         routes,
         services,
+        status,
       };
     });
   }
@@ -762,97 +822,145 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
     const {statefulSets} = this.props;
     return _.map(statefulSets.data, (ss) => {
       const buildConfigs = this.getBuildConfigsForResource(ss);
-      const obj = {
-        ...ss,
-        kind: StatefulSetModel.kind,
-      };
-      const readiness = {
-        desired: ss.spec.replicas || 0,
-        ready: ss.status.replicas || 0,
-      };
       const pods = this.getPodsForResource(ss);
       const alerts = combinePodAlerts(pods);
       const services = this.getServicesForResource(ss);
       const routes = this.getRoutesForServices(services);
+      const obj = {
+        ...ss,
+        apiVersion: apiVersionForModel(StatefulSetModel),
+        kind: StatefulSetModel.kind,
+      };
+      const status = <OverviewItemReadiness
+        desired={ss.spec.replicas}
+        ready={ss.status.replicas}
+        resource={obj}
+      />;
+
       return {
         alerts,
         buildConfigs,
         obj,
         pods,
-        readiness,
         routes,
         services,
+        status,
+      };
+    });
+  }
+
+  createPodItems(): OverviewItem[] {
+    const {pods} = this.props;
+    return _.reduce(pods.data, (acc, pod) => {
+      const owners = _.get(pod, 'metadata.ownerReferences');
+      const phase = _.get(pod, 'status.phase');
+      if (!_.isEmpty(owners) || ['Succeeded', 'Failed'].includes(phase)) {
+        return acc;
+      }
+
+      const obj = {
+        ...pod,
+        apiVersion: apiVersionForModel(PodModel),
+        kind: PodModel.kind,
+      };
+      const alerts = getPodAlerts(pod);
+      const services = this.getServicesForResource(obj);
+      const routes = this.getRoutesForServices(services);
+      const status = <PodStatus pod={pod} />;
+      return [
+        ...acc,
+        {
+          alerts,
+          obj,
+          routes,
+          services,
+          status,
+        },
+      ];
+    }, []);
+  }
+
+  createVirtualMachineItems(): OverviewItem[] {
+    const {virtualMachines} = this.props;
+    return _.map(_.get(virtualMachines, 'data'), vm => {
+      const obj = {
+        ...vm,
+        kind: VirtualMachineModel.kind,
+      };
+      const pods = this.getPodsForResource(vm);
+      const services = this.getServicesForResource(vm);
+      const routes = this.getRoutesForServices(services);
+      const resolvedPods = _.get(this.props.pods, 'data', []);
+      const migrations = _.get(this.props.vmMigrations, 'data', []);
+      const status = <VmStatus vm={vm} pods={resolvedPods} migrations={migrations} />;
+      return {
+        obj,
+        pods,
+        routes,
+        services,
+        status,
       };
     });
   }
 
   createOverviewData(): void {
-    const {loaded, updateResources} = this.props;
+    const {loaded, mock, selectedGroup, updateGroupOptions, updateSelectedGroup, updateResources} = this.props;
 
     if (!loaded) {
       return;
     }
+    // keeps deleted bookmarked projects from attempting to generate data
+    if (mock) {
+      return;
+    }
 
     const items = [
       ...this.createDaemonSetItems(),
       ...this.createDeploymentItems(),
       ...this.createDeploymentConfigItems(),
       ...this.createStatefulSetItems(),
+      ...this.createPodItems(),
+      ...this.createVirtualMachineItems(),
     ];
 
     updateResources(items);
 
     const filteredItems = this.filterItems(items);
     const { firstLabel, groupOptions } = this.getGroupOptionsFromLabels(filteredItems);
-    const selectedGroup = GROUP_BY_APPLICATION;
+    if (!_.has(groupOptions, selectedGroup)) {
+      updateSelectedGroup(OverviewSpecialGroup.GROUP_BY_APPLICATION);
+    }
+
+    updateGroupOptions(groupOptions);
     const groupedItems = groupItems(filteredItems, selectedGroup);
     this.setState({
       filteredItems,
       groupedItems,
       firstLabel,
-      groupOptions,
       items,
-      selectedGroup,
     });
   }
 
-  handleFilterChange = (event: any): void => {
-    this.setState({filterValue: event.target.value});
-  };
-
-  handleGroupChange = (selectedGroup: string): void => {
-    this.setState({selectedGroup});
-  };
-
-  clearFilter = (): void => {
-    this.setState({filterValue: ''});
-  };
-
   render() {
     const {loaded, loadError, mock, title, project = {}, selectedView} = this.props;
-    const {filteredItems, groupedItems, firstLabel, groupOptions, selectedGroup} = this.state;
+    const {filteredItems, groupedItems, firstLabel} = this.state;
     return <div className="co-m-pane">
       <OverviewHeading
         disabled={mock}
         firstLabel={firstLabel}
-        groupOptions={groupOptions}
-        handleFilterChange={this.handleFilterChange}
-        handleGroupChange={this.handleGroupChange}
-        selectedGroup={selectedGroup}
-        selectedView={selectedView}
         title={title}
         project={project.data}
       />
       <div className="co-m-pane__body co-m-pane__body--no-top-margin">
         <StatusBox
-          data={selectedView === View.Resources ? filteredItems : project}
+          data={selectedView === OverviewViewOption.RESOURCES ? filteredItems : project}
           label="Resources"
           loaded={loaded}
           loadError={loadError}
           EmptyMsg={OverviewEmptyState}
         >
-          {selectedView === View.Resources && <ProjectOverview groups={groupedItems} />}
-          {selectedView === View.Dashboard && <OverviewNamespaceDashboard obj={project.data} />}
+          {selectedView === OverviewViewOption.RESOURCES && <ProjectOverview groups={groupedItems} />}
+          {selectedView === OverviewViewOption.DASHBOARD && <OverviewNamespaceDashboard obj={project.data} />}
         </StatusBox>
       </div>
     </div>;
@@ -861,22 +969,24 @@ class OverviewMainContent_ extends React.Component<OverviewMainContentProps, Ove
 
 const OverviewMainContent = connect<OverviewMainContentPropsFromState, OverviewMainContentPropsFromDispatch, OverviewMainContentOwnProps>(mainContentStateToProps, mainContentDispatchToProps)(OverviewMainContent_);
 
-const overviewStateToProps = ({UI}): OverviewPropsFromState => {
+const overviewStateToProps = (state): OverviewPropsFromState => {
+  const { UI } = state;
   const selectedUID = UI.getIn(['overview', 'selectedUID']);
   const resources = UI.getIn(['overview', 'resources']);
   const selectedItem = !!resources && resources.get(selectedUID);
-  const selectedView = UI.getIn(['overview', 'selectedView'], View.Resources);
-  return { selectedItem, selectedView };
+  const kubevirtFlag = state[featureReducerName].get(FLAGS.KUBEVIRT);
+  const selectedView = UI.getIn(['overview', 'selectedView'], OverviewViewOption.RESOURCES);
+  return { selectedItem, selectedView, kubevirtFlag };
 };
 
-const overviewDispatchToProps = (dispatch) => {
+const overviewDispatchToProps = (dispatch): OverviewPropsFromDispatch => {
   return {
     dismissDetails: () => dispatch(UIActions.dismissOverviewDetails()),
   };
 };
 
-const Overview_: React.SFC<OverviewProps> = (({mock, namespace, selectedItem, selectedView, title, dismissDetails}) => {
-  const sidebarOpen = !_.isEmpty(selectedItem) && selectedView !== View.Dashboard;
+const Overview_: React.SFC<OverviewProps> = ({mock, namespace, selectedItem, selectedView, title, dismissDetails, kubevirtFlag}) => {
+  const sidebarOpen = !_.isEmpty(selectedItem) && selectedView !== OverviewViewOption.DASHBOARD;
   const className = classnames('overview', {'overview--sidebar-shown': sidebarOpen});
   // TODO: Update resources for native Kubernetes clusters.
   const resources = [
@@ -952,6 +1062,20 @@ const Overview_: React.SFC<OverviewProps> = (({mock, namespace, selectedItem, se
       namespace,
       prop: 'statefulSets',
     },
+    ...(kubevirtFlag && [
+      {
+        isList: true,
+        kind: VirtualMachineModel.kind,
+        namespace,
+        prop: 'virtualMachines',
+      },
+      {
+        isList: true,
+        kind: VirtualMachineInstanceMigrationModel.kind,
+        namespace,
+        prop: 'vmMigrations',
+      },
+    ] || []),
   ];
 
   return <div className={className}>
@@ -983,7 +1107,7 @@ const Overview_: React.SFC<OverviewProps> = (({mock, namespace, selectedItem, se
       </CSSTransition>
     }
   </div>;
-});
+};
 
 export const Overview = connect<OverviewPropsFromState, OverviewPropsFromDispatch, OverviewOwnProps>(overviewStateToProps, overviewDispatchToProps)(Overview_);
 
@@ -1029,26 +1153,21 @@ export type PodControllerOverviewItem = {
   pods: K8sResourceKind[];
 };
 
-type OverviewItemReadiness = {
-  desired: string | number;
-  ready: string | number;
-};
-
 export type BuildConfigOverviewItem = K8sResourceKind & {
   builds: K8sResourceKind[];
 };
 
 export type OverviewItem = {
   alerts?: OverviewItemAlerts;
-  buildConfigs: BuildConfigOverviewItem[];
+  buildConfigs?: BuildConfigOverviewItem[];
   current?: PodControllerOverviewItem;
   isRollingOut?: boolean;
   obj: K8sResourceKind;
   pods?: K8sResourceKind[];
   previous?: PodControllerOverviewItem;
-  readiness: OverviewItemReadiness;
   routes: K8sResourceKind[];
   services: K8sResourceKind[];
+  status?: React.ReactNode;
 };
 
 export type OverviewGroup = {
@@ -1065,22 +1184,28 @@ export type OverviewMetrics = {
   memory?: MetricValuesByPod;
 };
 
+type OverviewItemReadinessProps = {
+  desired: number;
+  resource: K8sResourceKind;
+  ready: number;
+};
+
 type OverviewHeadingPropsFromState = {
-  selectedView: View;
+  filterValue: string;
+  groupOptions: {[key: string]: string};
+  selectedGroup: string;
+  selectedView: OverviewViewOption;
 };
 
 type OverviewHeadingPropsFromDispatch = {
-  selectView: (view: View) => void;
+  selectView: (view: OverviewViewOption) => void;
+  selectGroup: (selectedLabel: string) => void;
+  changeFilter: (value: string) => void;
 };
 
 type OverviewHeadingOwnProps = {
   disabled?: boolean;
   firstLabel?: string;
-  groupOptions?: any;
-  handleFilterChange?: (event: any) => void;
-  handleGroupChange?: (selectedLabel: string) => void;
-  selectedGroup?: string;
-  selectedView?: string;
   title: string;
   project: K8sResourceKind;
 };
@@ -1088,13 +1213,18 @@ type OverviewHeadingOwnProps = {
 type OverviewHeadingProps = OverviewHeadingPropsFromState & OverviewHeadingPropsFromDispatch & OverviewHeadingOwnProps;
 
 type OverviewMainContentPropsFromState = {
+  filterValue: string;
+  groupOptions: {[key: string]: string};
   metrics: OverviewMetrics;
-  selectedView: View;
+  selectedGroup: string;
+  selectedView: OverviewViewOption;
 };
 
 type OverviewMainContentPropsFromDispatch = {
+  updateGroupOptions: (groups: {[key: string]:string}) => void;
   updateMetrics: (metrics: OverviewMetrics) => void;
   updateResources: (items: OverviewItem[]) => void;
+  updateSelectedGroup: (group: string) => void;
 };
 
 type OverviewMainContentOwnProps = {
@@ -1116,23 +1246,23 @@ type OverviewMainContentOwnProps = {
   selectedItem: OverviewItem;
   statefulSets?: FirehoseList;
   title?: string;
+  virtualMachines?: FirehoseList;
+  vmMigrations?: FirehoseList;
 };
 
 type OverviewMainContentProps = OverviewMainContentPropsFromState & OverviewMainContentPropsFromDispatch & OverviewMainContentOwnProps;
 
 type OverviewMainContentState = {
-  readonly filterValue: string;
   readonly items: any[];
   readonly filteredItems: any[];
   readonly groupedItems: any[];
   readonly firstLabel: string;
-  readonly groupOptions: any;
-  readonly selectedGroup: string;
 };
 
 type OverviewPropsFromState = {
   selectedItem: any;
-  selectedView: View;
+  kubevirtFlag?: boolean;
+  selectedView: OverviewViewOption;
 };
 
 type OverviewPropsFromDispatch = {
