@@ -6,7 +6,7 @@ import { Helmet } from 'react-helmet';
 import { Link } from 'react-router-dom';
 
 import { LoadingBox, LoadError } from './utils/status-box';
-import { Dropdown, Firehose, history, MsgBox, NsDropdown, ResourceName } from './utils';
+import { Dropdown, Firehose, history, MsgBox, NsDropdown, ResourceName, ExternalLink } from './utils';
 import { BuildConfigModel, DeploymentConfigModel, ImageStreamModel, ImageStreamTagModel, RouteModel, ServiceModel } from '../models';
 import { ContainerPort, k8sCreate, k8sGet, K8sResourceKind } from '../module/k8s';
 import { ImageStreamIcon } from './catalog/catalog-item-icon';
@@ -79,7 +79,7 @@ const ImageStreamInfo: React.SFC<ImageStreamInfoProps> = ({imageStream, tag}) =>
       </div>
     </div>
     {description && <p className="co-catalog-item-details__description">{description}</p>}
-    {sampleRepo && <p>Sample repository: <a href={sampleRepo} target="_blank" rel="noopener noreferrer">{sampleRepo}</a></p>}
+    {sampleRepo && <p>Sample repository: <ExternalLink href={sampleRepo} text={sampleRepo} /></p>}
     <SourceToImageResourceDetails />
   </div>;
 };
@@ -219,10 +219,10 @@ class BuildSource extends React.Component<BuildSourceProps, BuildSourceState> {
           },
         },
         source: {
+          contextDir,
           git: {
             uri: repository,
             ref,
-            contextDir,
             type: 'Git',
           },
         },
@@ -457,7 +457,7 @@ class BuildSource extends React.Component<BuildSourceProps, BuildSourceState> {
             </div>}
             <div className="help-block">
               For private Git repositories,
-              create a <Link to={`/k8s/ns/${this.state.namespace || 'default'}/secrets/new/source`}>source secret</Link>.
+              create a <Link to={`/k8s/ns/${this.state.namespace || 'default'}/secrets/~new/source`}>source secret</Link>.
             </div>
           </div>
           {!_.isEmpty(ports) && <div className="form-group">
