@@ -9,6 +9,10 @@ import { kindToAbbr } from '../../module/k8s/get-resources';
 const MEMO = {};
 
 export const ResourceIcon: React.SFC<ResourceIconProps> = ({className, kind}) => {
+  // if no kind, return null so an empty icon isn't rendered
+  if (!kind) {
+    return null;
+  }
   const memoKey = className ? `${kind}/${className}` : kind;
   if (MEMO[memoKey]) {
     return MEMO[memoKey];
@@ -41,6 +45,6 @@ export type ResourceNameProps = {
 };
 /* eslint-enable no-undef */
 
-export const ResourceName: React.SFC<ResourceNameProps> = (props) => <span className="co-resource-link"><ResourceIcon kind={props.kind} /> <span className="co-resource-link__resource-name">{props.name}</span></span>;
+export const ResourceName: React.SFC<ResourceNameProps> = (props) => <span className="co-resource-item"><ResourceIcon kind={props.kind} /> <span className="co-resource-item__resource-name">{props.name}</span></span>;
 
 ResourceName.displayName = 'ResourceName';
