@@ -1,6 +1,5 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
-import * as classNames from 'classnames';
 import {VolumeSource} from '../../module/k8s/pods';
 
 export const VolumeIcon = ({kind}) => {
@@ -11,8 +10,8 @@ export const VolumeIcon = ({kind}) => {
   ]);
   const faClass = faClasses[kind];
 
-  return <span className={`co-m-volume-icon co-m-volume-icon--${kind}`}>
-    {faClass && <i className={classNames('fa', faClass)}></i>}
-    <span>{_.get(VolumeSource[kind], 'label', '')}</span>
+  return <span className="co-icon-and-text co-m-volume-icon">
+    {faClass && <i className={`fa ${faClass} co-icon-and-text__icon`}></i>}
+    {_.get(VolumeSource[kind], 'label', '')}
   </span>;
 };
