@@ -5,8 +5,8 @@ export const CatalogSourceConfigModel: K8sKind = {
   kind: 'CatalogSourceConfig',
   label: 'CatalogSourceConfig',
   labelPlural: 'CatalogSourceConfigs',
-  apiGroup: 'marketplace.redhat.com',
-  apiVersion: 'v1alpha1',
+  apiGroup: 'operators.coreos.com',
+  apiVersion: 'v1',
   path: 'catalogsourceconfigs',
   abbr: 'CSC',
   namespaced: true,
@@ -18,8 +18,8 @@ export const OperatorSourceModel: K8sKind = {
   kind: 'OperatorSource',
   label: 'OperatorSource',
   labelPlural: 'OperatorSource',
-  apiGroup: 'marketplace.redhat.com',
-  apiVersion: 'v1alpha1',
+  apiGroup: 'operators.coreos.com',
+  apiVersion: 'v1',
   path: 'operatorsources',
   abbr: 'OSRC',
   namespaced: true,
@@ -44,8 +44,8 @@ export const PackageManifestModel: K8sKind = {
   kind: 'PackageManifest',
   label: 'PackageManifest',
   labelPlural: 'PackageManifests',
-  apiGroup: 'packages.apps.redhat.com',
-  apiVersion: 'v1alpha1',
+  apiGroup: 'packages.operators.coreos.com',
+  apiVersion: 'v1',
   path: 'packagemanifests',
   abbr: 'PM',
   namespaced: true,
@@ -98,7 +98,7 @@ export const OperatorGroupModel: K8sKind = {
   label: 'OperatorGroup',
   labelPlural: 'OperatorGroups',
   apiGroup: 'operators.coreos.com',
-  apiVersion: 'v1alpha2',
+  apiVersion: 'v1',
   path: 'operatorgroups',
   abbr: 'OG',
   namespaced: true,
@@ -555,45 +555,6 @@ export const SelfSubjectAccessReviewModel: K8sKind = {
   labelPlural: 'Self Subject Access Reviews',
 };
 
-export const TectonicVersionModel: K8sKind = {
-  label: 'Tectonic Version',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'tectonicversions',
-  plural: 'tectonicversions',
-  abbr: 'TV',
-  namespaced: true,
-  kind: 'TectonicVersion',
-  id: 'tectonicversion',
-  labelPlural: 'Tectonic Versions',
-};
-
-export const ChannelOperatorConfigModel: K8sKind = {
-  label: 'Channel Operator Config',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'channeloperatorconfigs',
-  plural: 'channeloperatorconfigs',
-  abbr: 'COC',
-  namespaced: true,
-  kind: 'ChannelOperatorConfig',
-  id: 'channeloperatorconfig',
-  labelPlural: 'Channel Operator Configs',
-};
-
-export const AppVersionModel: K8sKind = {
-  label: 'AppVersion',
-  apiGroup: 'tco.coreos.com',
-  apiVersion: 'v1',
-  path: 'appversions',
-  plural: 'appversions',
-  abbr: 'AV',
-  namespaced: true,
-  kind: 'AppVersion',
-  id: 'appversion',
-  labelPlural: 'AppVersions',
-};
-
 export const PersistentVolumeModel: K8sKind = {
   label: 'Persistent Volume',
   apiVersion: 'v1',
@@ -732,6 +693,7 @@ export const ClusterServiceBrokerModel: K8sKind = {
   namespaced: false,
   kind: 'ClusterServiceBroker',
   id: 'clusterservicebroker',
+  crd: true,
 };
 
 export const ClusterServiceClassModel: K8sKind = {
@@ -745,6 +707,7 @@ export const ClusterServiceClassModel: K8sKind = {
   namespaced: false,
   kind: 'ClusterServiceClass',
   id: 'clusterserviceclass',
+  crd: true,
 };
 
 export const ClusterServicePlanModel: K8sKind = {
@@ -758,6 +721,7 @@ export const ClusterServicePlanModel: K8sKind = {
   namespaced: false,
   kind: 'ClusterServicePlan',
   id: 'clusterserviceplan',
+  crd: true,
 };
 
 export const ServiceInstanceModel: K8sKind = {
@@ -771,6 +735,7 @@ export const ServiceInstanceModel: K8sKind = {
   namespaced: true,
   kind: 'ServiceInstance',
   id: 'serviceinstance',
+  crd: true,
 };
 
 export const ServiceBindingModel: K8sKind = {
@@ -784,9 +749,12 @@ export const ServiceBindingModel: K8sKind = {
   namespaced: true,
   kind: 'ServiceBinding',
   id: 'servicebinding',
+  crd: true,
 };
 
 export * from '../kubevirt/models/vm'; // needed when setting features and resource pages
+export * from '../metalkube/models/host'; // needed when setting features and resource pages
+export * from '../storage/models/storage'; // needed when setting features and resource pages
 
 export const LimitRangeModel: K8sKind = {
   label: 'Limit Range',
@@ -815,13 +783,27 @@ export const APIServiceModel: K8sKind = {
 };
 
 // Cluster API resources
-// https://github.com/kubernetes-sigs/cluster-api
+// https://github.com/openshift/cluster-api
+export const MachineModel: K8sKind = {
+  label: 'Machine',
+  labelPlural: 'Machines',
+  apiVersion: 'v1beta1',
+  path: 'machines',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machines',
+  abbr: 'M',
+  namespaced: true,
+  kind: 'Machine',
+  id: 'machine',
+  crd: true,
+};
+
 export const MachineSetModel: K8sKind = {
   label: 'Machine Set',
   labelPlural: 'Machine Sets',
-  apiVersion: 'v1alpha1',
+  apiVersion: 'v1beta1',
   path: 'machinesets',
-  apiGroup: 'cluster.k8s.io',
+  apiGroup: 'machine.openshift.io',
   plural: 'machinesets',
   abbr: 'MS',
   namespaced: true,
@@ -830,17 +812,45 @@ export const MachineSetModel: K8sKind = {
   crd: true,
 };
 
-export const MachineModel: K8sKind = {
-  label: 'Machine',
-  labelPlural: 'Machines',
-  apiVersion: 'v1alpha1',
-  path: 'machines',
-  apiGroup: 'cluster.k8s.io',
-  plural: 'machines',
-  abbr: 'M',
+export const MachineDeploymentModel: K8sKind = {
+  label: 'Machine Deployment',
+  labelPlural: 'Machine Deployments',
+  apiVersion: 'v1beta1',
+  path: 'machinedeployments',
+  apiGroup: 'machine.openshift.io',
+  plural: 'machinedeployments',
+  abbr: 'MD',
   namespaced: true,
-  kind: 'Machine',
-  id: 'machine',
+  kind: 'MachineDeployment',
+  id: 'machinedeployment',
+  crd: true,
+};
+
+export const MachineConfigPoolModel: K8sKind = {
+  label: 'Machine Config Pool',
+  labelPlural: 'Machine Config Pools',
+  apiVersion: 'v1',
+  path: 'machineconfigpools',
+  apiGroup: 'machineconfiguration.openshift.io',
+  plural: 'machineconfigpools',
+  abbr: 'MCP',
+  namespaced: false,
+  kind: 'MachineConfigPool',
+  id: 'machineconfigpool',
+  crd: true,
+};
+
+export const MachineConfigModel: K8sKind = {
+  label: 'Machine Config',
+  labelPlural: 'Machine Configs',
+  apiVersion: 'v1',
+  path: 'machineconfigs',
+  apiGroup: 'machineconfiguration.openshift.io',
+  plural: 'machineconfigs',
+  abbr: 'MC',
+  namespaced: false,
+  kind: 'MachineConfig',
+  id: 'machineconfigpool',
   crd: true,
 };
 
@@ -886,3 +896,18 @@ export const ClusterAutoscalerModel: K8sKind = {
   id: 'clusterautoscaler',
   crd: true,
 };
+
+// OpenShift global configuration
+export const OAuthModel: K8sKind = {
+  label: 'OAuth',
+  labelPlural: 'OAuths',
+  apiVersion: 'v1',
+  path: 'oauths',
+  apiGroup: 'config.openshift.io',
+  plural: 'oauths',
+  abbr: 'OA',
+  namespaced: false,
+  kind: 'OAuth',
+  id: 'oauth',
+  crd: true,
+};
