@@ -137,10 +137,6 @@ kind: BuildConfig
 metadata:
   name: example
 spec:
-  output:
-    to:
-      kind: ImageStreamTag
-      name: example:latest
   source:
     git:
       ref: master
@@ -704,7 +700,7 @@ apiVersion: v1
 kind: ResourceQuota
 metadata:
   name: compute-quota
-  namespace: 
+  namespace:
 spec:
   hard:
     requests.cpu: '1'
@@ -716,7 +712,7 @@ apiVersion: v1
 kind: ResourceQuota
 metadata:
   name: storage-class-quota
-  namespace: 
+  namespace:
 spec:
   hard:
     requests.storage: 100Gi
@@ -733,7 +729,7 @@ apiVersion: v1
 kind: ResourceQuota
 metadata:
   name: object-counts
-  namespace: 
+  namespace:
 spec:
   hard:
     configmaps: "10"
@@ -747,26 +743,60 @@ apiVersion: "autoscaling.openshift.io/v1alpha1"
 kind: "ClusterAutoscaler"
 metadata:
   name: "default"
+spec: {}
+`).setIn([referenceForModel(k8sModels.MachineDeploymentModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: MachineDeployment
+metadata:
+  name: example
 spec:
-  podPriorityThreshold: -10
-  resourceLimits:
-    maxNodesTotal: 24
-    cores:
-      min: 8
-      max: 128
-    memory:
-      min: 4
-      max: 256
-    gpus:
-      - type: nvidia.com/gpu
-        min: 0
-        max: 16
-      - type: amd.com/gpu
-        min: 0
-        max: 4
-  scaleDown:
-    enabled: true
-    delayAfterAdd: 10s
-    delayAfterDelete: 10s
-    delayAfterFailure: 10s
-`).setIn([referenceForModel(k8sModels.VirtualMachineModel), 'default'], vmYamlTemplate);
+  replicas: 3
+  selector:
+    matchLabels:
+      foo: bar
+  template:
+    metadata:
+      labels:
+        foo: bar
+    spec:
+      providerSpec: {}
+      versions:
+        kubelet: ""
+`).setIn([referenceForModel(k8sModels.MachineSetModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: MachineSet
+metadata:
+  name: example
+spec:
+  replicas: 3
+  selector:
+    matchLabels:
+      foo: bar
+  template:
+    metadata:
+      labels:
+        foo: bar
+    spec:
+      providerSpec: {}
+      versions:
+        kubelet: ""
+`).setIn([referenceForModel(k8sModels.MachineModel), 'default'], `
+apiVersion: "machine.openshift.io/v1beta1"
+kind: Machine
+metadata:
+  name: example
+spec:
+  providerSpec: {}
+`).setIn([referenceForModel(k8sModels.VirtualMachineModel), 'default'], vmYamlTemplate).setIn([referenceForModel(k8sModels.MachineConfigPoolModel), 'default'], `
+apiVersion: machineconfiguration.openshift.io/v1
+kind: MachineConfigPool
+metadata:
+  name: example
+spec:
+  machineConfigSelector:
+    matchLabels:
+      machineconfiguration.openshift.io/role: master
+  machineSelector:
+    matchLabels:
+      node-role.kubernetes.io/master: ""
+`);
